@@ -3,7 +3,7 @@ import logging
 from tqdm import tqdm
 
 
-LOGGER = logging.getLogger()
+LOGGER = logging.getLogger(__name__)
 
 
 class logging_tqdm(tqdm):
@@ -35,5 +35,5 @@ class logging_tqdm(tqdm):
             # skip progress bar before having processed anything
             return
         if not msg:
-            msg = self.__repr__()
+            msg = self.__str__()
         self.logger.info('%s', msg)
